#!/usr/bin/env python
# -*- coding: utf-8 -*-

default_kws = {
  'page' : False,
  'paginate' : True,
  'concurrent': False,
  'num_workers': 20,
  'since_id': None,
  'throttle' : 1,
  'limit' : 100,
  'wait': 1,
  'backoff': 2,
  'timeout': 30 
}
